@@ -1,5 +1,5 @@
 # Licensed under the Apache License: http://www.apache.org/licenses/LICENSE-2.0
-# For details: https://github.com/nedbat/coveragepy/blob/master/NOTICE.txt
+# For details: https://github.com/coveragepy/coveragepy/blob/main/NOTICE.txt
 
 """Tests for core selection of coverage.py."""
 
@@ -11,6 +11,7 @@ import coverage
 from coverage import env
 from coverage.exceptions import ConfigError
 
+from tests import testenv
 from tests.coveragetest import CoverageTest
 from tests.helpers import re_line, re_lines
 
@@ -73,19 +74,22 @@ class CoverageCoreTest(CoverageTest):
         core = re_line(r" core:", out).strip()
         assert core == "core: PyTracer"
 
+    @pytest.mark.skipif(
+        env.METACOV and env.PYBEHAVIOR.pep669 and not testenv.CAN_MEASURE_BRANCHES,
+        reason="12/13 can't do branches with sysmon, so metacov is too complicated",
+    )
     def test_core_request_sysmon(self) -> None:
         self.set_environ("COVERAGE_CORE", "sysmon")
+        out = self.run_command("coverage run --debug=sys numbers.py")
+        assert out.endswith("123 456\n")
+        core = re_line(r" core:", out).strip()
+        warns = re_lines(r"\(no-sysmon\)", out)
         if env.PYBEHAVIOR.pep669:
-            status = 0
-        else:
-            status = 1
-        out = self.run_command("coverage run --debug=sys numbers.py", status=status)
-        if status == 0:
-            assert out.endswith("123 456\n")
-            core = re_line(r" core:", out).strip()
             assert core == "core: SysMonitor"
+            assert not warns
         else:
-            assert "Can't use core=sysmon: sys.monitoring isn't available in this version;" in out
+            assert core in ["core: CTracer", "core: PyTracer"]
+            assert warns
 
     def test_core_request_sysmon_no_dyncontext(self) -> None:
         # Use config core= for this test just to be different.
@@ -97,11 +101,19 @@ class CoverageCoreTest(CoverageTest):
             dynamic_context = test_function
             """,
         )
-        out = self.run_command("coverage run --debug=sys numbers.py", status=1)
+        out = self.run_command("coverage run --debug=sys numbers.py")
+        assert out.endswith("123 456\n")
+        core = re_line(r" core:", out).strip()
+        assert core in ["core: CTracer", "core: PyTracer"]
+        warns = re_lines(r"\(no-sysmon\)", out)
+        assert len(warns) == 1
         if env.PYBEHAVIOR.pep669:
-            assert "Can't use core=sysmon: it doesn't yet support dynamic contexts;" in out
+            assert (
+                "Can't use core=sysmon: it doesn't yet support dynamic contexts, using default core"
+                in warns[0]
+            )
         else:
-            assert "Can't use core=sysmon: sys.monitoring isn't available in this version;" in out
+            assert "sys.monitoring isn't available in this version, using default core" in warns[0]
 
     def test_core_request_sysmon_no_branches(self) -> None:
         # Use config core= for this test just to be different.
@@ -113,21 +125,25 @@ class CoverageCoreTest(CoverageTest):
             branch = True
             """,
         )
+        out = self.run_command("coverage run --debug=sys numbers.py")
+        assert out.endswith("123 456\n")
+        core = re_line(r" core:", out).strip()
+        warns = re_lines(r"\(no-sysmon\)", out)
         if env.PYBEHAVIOR.branch_right_left:
-            status = 0
-        elif env.PYBEHAVIOR.pep669:
-            status = 1
-            msg = "Can't use core=sysmon: sys.monitoring can't measure branches in this version;"
-        else:
-            status = 1
-            msg = "Can't use core=sysmon: sys.monitoring isn't available in this version;"
-        out = self.run_command("coverage run --debug=sys numbers.py", status=status)
-        if status == 0:
-            assert out.endswith("123 456\n")
-            core = re_line(r" core:", out).strip()
             assert core == "core: SysMonitor"
+            assert not warns
         else:
-            assert msg in out  # pylint: disable=possibly-used-before-assignment
+            assert core in ["core: CTracer", "core: PyTracer"]
+            assert len(warns) == 1
+            if env.PYBEHAVIOR.pep669:
+                assert (
+                    "sys.monitoring can't measure branches in this version, using default core"
+                    in warns[0]
+                )
+            else:
+                assert (
+                    "sys.monitoring isn't available in this version, using default core" in warns[0]
+                )
 
     def test_core_request_nosuchcore(self) -> None:
         # Test the coverage misconfigurations in-process with pytest. Running a
